summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmcameraedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmcameraedit.h')
-rw-r--r--kpovmodeler/pmcameraedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmcameraedit.h b/kpovmodeler/pmcameraedit.h
index a9ed5ee9..33b9c39b 100644
--- a/kpovmodeler/pmcameraedit.h
+++ b/kpovmodeler/pmcameraedit.h
@@ -41,12 +41,13 @@ class TQCheckBox;
class PMCameraEdit : public PMNamedObjectEdit
{
Q_OBJECT
+ TQ_OBJECT
typedef PMNamedObjectEdit Base;
public:
/**
* Creates a PMCameraEdit with parent and name
*/
- PMCameraEdit( TQWidget* parent, const char* name = 0 );
+ PMCameraEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -41,12 +41,13 @@ class TQCheckBox;
public:
/**
- * Creates a PMCameraEdit with parent and name
+ * Creates a PMCameraEdit with tqparent and name
*/